@@ -77,6 +77,31 @@ class Scene(models.Model):
             layer.order = order
             layer.save()
 
+    def insert_in_tree(self, layer, parts):
+        """ Add the layer in tree. Each parts are a group name to find inside the tree.
+            Here we assume that missing groups are added at first position of current node
+            We create missing group with default exclusive group configuration (should be corrected later if necessary)
+        """
+
+        current_node = self.tree
+        for part in parts:
+            found = False
+            for group in current_node:
+                if group.get("group") and group["label"] == part:
+                    current_node = group["children"]
+                    found = True
+                    break
+            if not found:
+                # Add the missing group
+                new_group = {"group": True, "label": part, "children": []}
+                current_node.insert(0, new_group)
+                current_node = new_group["children"]
+
+        # Node if found (or created) we can add the geolayer now
+        current_node.append({"geolayer": layer.id, "label": layer.name})
+
+        self.save()
+
     def save(self, *args, **kwargs):
         if not self.slug:
             self.slug = slugify(self.name)
